# Copyright (c) 2001 bivio Inc.  All rights reserved.
#
# This program is free software and is provided "as is" without express
# or implied warranty.  It may be used, redistributed, and/or modified
# under the terms of the Perl Artistic License:
# http://www.opensource.org/licenses/artistic-license.html
# 
# $Id: BConf.pm,v 1.2 2001/07/29 21:42:44 nagler Exp $
package BivioNet::BConf;
use strict;
$BivioNet::BConf::VERSION = sprintf('%d.%02d', q$Revision: 1.2 $ =~ /\d+/g);
$_ = $BivioNet::BConf::VERSION;

=head1 NAME

BivioNet::BConf - default www.bivio.net configuration

=head1 RELEASE SCOPE

bOP

=head1 SYNOPSIS

    use BivioNet::BConf;

=cut

use Bivio::UNIVERSAL;
@BivioNet::BConf::ISA = ('Bivio::UNIVERSAL');

=head1 DESCRIPTION

C<BivioNet::BConf> default www.bivio.net configuration.

=cut

#=IMPORTS
use Bivio::IO::Config;

#=VARIABLES
my($_DEFAULT_CONFIG) = {
    # use the production config by default
    'Bivio::IO::ClassLoader' => {
	delegates => {
	    'Bivio::Agent::TaskId' => 'BivioNet::Agent::TaskId',
	    'Bivio::Agent::HTTP::Cookie' => 'Bivio::Delegate::NoCookie',
	    'Bivio::Auth::Permission' => 'Bivio::Delegate::SimplePermission',
	    'Bivio::UI::FacadeChildType' =>
	            'Bivio::Delegate::SimpleFacadeChildType',
	    'Bivio::UI::HTML::FormErrors' =>
	            'Bivio::Delegate::SimpleFormErrors',
	    'Bivio::UI::HTML::WidgetFactory' =>
	    	    'Bivio::Delegate::SimpleWidgetFactory',
	    'Bivio::TypeError' => 'Bivio::Delegate::SimpleTypeError',
	    'Bivio::Type::RealmName' => 'Bivio::Delegate::SimpleRealmName',
	    'Bivio::Auth::Support' => 'Bivio::Delegate::NoDbAuthSupport',
	},
	maps => {
	    Model => ['Bivio::Biz::Model'],
	    Type => ['Bivio::Type'],
	    HTMLWidget => ['Bivio::UI::HTML::Widget', 'Bivio::UI::Widget'],
	    HTMLFormat => ['Bivio::UI::HTML::Format'],
	    MailWidget => ['Bivio::UI::Mail::Widget', 'Bivio::UI::Widget'],
	    FacadeComponent => ['Bivio::UI'],
	    Facade => ['BivioNet::Facade'],
	    Action => ['Bivio::Biz::Action'],
	},
    },
    'Bivio::UI::Facade' => {
        default => 'BivioNet',
	# Note: local_file_prefix is '.', but we might share the root
	# with other facades.
	local_file_root => '/home/httpd/files',
    },
    'Bivio::UI::Text' => {
	http_host => 'www.bivio.net',
	mail_host => 'bivio.net',
    },
    'Bivio::Die' => {
	stack_trace_error => 1,
    },
    'Bivio::Ext::DBI' => {
	oracle_home => '/usr/local/oracle/product/8.1.6',
	database => 'none',
	user => 'none',
	password => 'none',
    },
    'Bivio::IO::Alert' => {
	intercept_warn => 1,
	stack_trace_warn => 1,
	want_pid => 0,
	want_stderr => 1,
	want_time => 1,
    },
    'Bivio::IO::Trace' => {
    },
    'Bivio::Type::Secret' => {
	key => 'alphabet soup',
    },
    main => {
	http => {
	    port => '80',
	},
    },
};

=head1 METHODS

=cut

=for html <a name="dev"></a>

=head2 dev(int port, hash_ref overrides) : hash_ref

Development environment configuration.

=cut

sub dev {
    my($proto, $port, $overrides) = @_;
    my($pwd) = `pwd`;
    chomp($pwd);
    die('must be run from perl/BivioNet directory')
	    unless $pwd =~ /BivioNet$/;
    # Make sure BivioNet symlink exists
    symlink('.', 'files/www.bivio.net') unless -l 'files/www.bivio.net';
    my($host) = `hostname`;
    chomp($host);
    return Bivio::IO::Config->merge($overrides || {},
	    $proto->merge({
		'Bivio::Agent::Request' => {
		    can_secure => 0,
		},
		'Bivio::Ext::DBI' => {
		    database => 'dev',
		},
		'Bivio::UI::FacadeComponent' => {
		    die_on_error => 1,
		},
		'Bivio::UI::Facade' => {
		    local_file_root => "$pwd/files",
		    want_local_file_cache => 0,
		},
		'Bivio::UI::Text' => {
		    http_host => "$host:$port",
		    mail_host => $host,
		},
		main => {
		    http => {
			port => $port,
		    },
		},
	    }));
}

=for html <a name="merge"></a>

=head2 merge(hash_ref custom) : hash_ref

Uses I<custom> config to override default config defined in this
module.

=cut

sub merge {
    my($proto, $config) = @_;

    # make a copy of the default, then add the supplied config recursively
    return Bivio::IO::Config->merge($config, $_DEFAULT_CONFIG);
}

#=PRIVATE METHODS

=head1 COPYRIGHT

Copyright (c) 2001 bivio Inc.  All rights reserved.

This program is free software and is provided "as is" without express
or implied warranty.  It may be used, redistributed, and/or modified
under the terms of the Perl Artistic License:
http://www.opensource.org/licenses/artistic-license.html

=head1 VERSION

$Id: BConf.pm,v 1.2 2001/07/29 21:42:44 nagler Exp $

=cut

1;
