# Copyright (c) 2000 bivio Inc.  All rights reserved.
#
# This program is free software and is provided "as is" without express
# or implied warranty.  It may be used, redistributed, and/or modified
# under the terms of the Perl Artistic License:
# http://www.opensource.org/licenses/artistic-license.html
# 
# $Id: BivioNet.pm,v 1.2 2001/06/27 20:18:35 nagler Exp $
package BivioNet::UI::Facade::BivioNet;
use strict;
$BivioNet::UI::Facade::BivioNet::VERSION = sprintf('%d.%02d', q$Revision: 1.2 $ =~ /\d+/g);
$_ = $BivioNet::UI::Facade::BivioNet::VERSION;

=head1 NAME

BivioNet::UI::Facade::BivioNet - main production and default facade

=head1 RELEASE SCOPE

bOP

=head1 SYNOPSIS

    use BivioNet::UI::Facade::BivioNet;

=cut

=head1 EXTENDS

L<Bivio::UI::Facade>

=cut

use Bivio::UI::Facade;
@BivioNet::UI::Facade::BivioNet::ISA = ('Bivio::UI::Facade');

=head1 DESCRIPTION

C<BivioNet::UI::Facade::BivioNet> is the main production and default Facade.

=cut

#=IMPORTS
use Bivio::UI::HTML::ViewShortcuts;

#=VARIABLES
my($_VS) = 'Bivio::UI::HTML::ViewShortcuts';

my($_SELF) = __PACKAGE__->new({
    clone => undef,
    is_production => 0,
    uri => 'www.bivio.net',
    Color => {
	initialize => sub {
	    my($fc) = @_;

	    #
	    # Links
	    #
	    $fc->group(page_link => 0x330099);
	    $fc->group(['page_vlink', 'page_alink'] => 0x330099);
            $fc->group(page_link_hover => 0xCC9900);

	    #
	    # Text
	    #
	    $fc->group(page_text => 0x000000);
	    $fc->group(page_bg => 0xFFFFFF);

#	    $fc->group(slide_heading => 0xFFCC33);
	    $fc->group(slide_heading => 0x006666);

	    # Basic emphasized text
	    $fc->group(page_heading => 0x0021A3);

	    $fc->group(['error', 'warning'] => 0x993300);

	    #
	    # Table
	    #
	    $fc->group(table_heading => -1);

            $fc->group(table_even_row_bg => 0xF3F3F3);
	    $fc->group(table_odd_row_bg => 0xFFFFFF);
	    $fc->group(table_separator => 0x000000);
            $fc->group(summary_line => 0x66CC66);

	    #
	    # BivioNet
	    #
	    $fc->group(bar_green => 0x006600);
	    $fc->group(facts_gray => 0x333333);
	    return;
	},
    },
    Font => {
	initialize => sub {
	    my($fc) = @_;
	    $fc->group(default => [
		'family=arial,sans-serif',
		'size=x-small',
	    ]);

	    $fc->group(slide_text => ['size=medium']);
	    $fc->group(slide_heading => ['size=large']);

	    $fc->group(error_icon => ['color=error', 'larger', 'bold']);
	    $fc->group(page_heading => ['bold', 'larger']);
	    $fc->group([qw(
                    table_heading
		    normal_table_heading
            )],
		    ['color=table_heading', 'bold'],
		   );
	    $fc->group(form_field_error => ['color=error', 'smaller', 'bold']);
	    $fc->group([qw(
		    error
		    warning
            )],
		   ['color=error', 'bold']);
	    $fc->group(form_field_error_label => ['color=error', 'italic']);
	    $fc->group(['list_error', 'checkbox_error'] =>
		   ['color=error', 'smaller']);
	    $fc->group(italic => ['italic']);
	    $fc->group([qw(
                    strong
                    table_row_title
            )],
		   ['bold']);
	    $fc->group([qw(
		    form_field_description
		    form_field_label
		    table_cell
		    number_cell
                    action_button
	            radio
                    descriptive_page
                    page_legend
                    checkbox
                    page_text
                    input_field
                    search_field
                    mailto
                    link
            )],
		   []);

	    $fc->group(menu => ['larger']);
	    $fc->group(selected_menu => ['larger']);
	    $fc->group(left_menu_text => []);
	    $fc->group(left_menu_heading => ['bold']);
	    $fc->group(left_menu_action => ['smaller']);
	    return;
	}
    },
    Text => {
	initialize => \&_text,
    },
    Task => {
	initialize => \&_task,
    },
    HTML => {
	initialize => sub {
	    my($fc) = @_;
	    $fc->group(want_secure => 0);
	    $fc->group(table_default_align => 'left');
	    return;
	},
    },
});

=head1 METHODS

=cut

#=PRIVATE METHODS

# _task(Bivio::UI::Text t)
#
# Decls here just to be cleaner.
#
sub _task {
    my($t) = @_;
    # Only icons are plain files
    $t->group(LOCAL_FILE_PLAIN => ['/i/*']);

    # See also view_execute_uri_prefix
    $t->group(SITE_ROOT => ['/*']);

    # Indicate that we don't have any realms.
    $t->group(USER_HOME => undef);
    $t->group(CLUB_HOME => undef);
    $t->group(MY_CLUB_SITE => undef);
    $t->group(MY_SITE => undef);

    # Tasks defined by this application

    # We want to be able to view source as plain text from the slides
    # the are on.
    $t->group(VIEW_AS_PLAIN_TEXT => ['/vs/*']);
    return;
}

# _text(Bivio::UI::Text t)
#
# Decls here just to be cleaner
#
sub _text {
    my($t) = @_;

    # Where to redirect to when coming in via /, i.e. http://www.kellogg.org
    $t->group(home_page_uri => '/hm');

    # SITE_ROOT task calls View->execute_uri and we look for pages in
    # the "site_root" directory.
    $t->group(view_execute_uri_prefix => 'site_root/');

    $t->group(none => '');
    $t->group(Image_alt => [
	prev_w_off => 'No previous slide',
	prev_w_on => 'Previous slide',
	next_w_off => 'No more slides',
	next_w_on => 'Next slide',
	back_w_off => 'First slide',
	back_w_on => 'Back to first slide',
	attachment_w_on => 'Download source for this view',
    ]);

    return;
}

=head1 COPYRIGHT

Copyright (c) 2000 bivio Inc.  All rights reserved.

This program is free software and is provided "as is" without express
or implied warranty.  It may be used, redistributed, and/or modified
under the terms of the Perl Artistic License:
http://www.opensource.org/licenses/artistic-license.html

=head1 VERSION

$Id: BivioNet.pm,v 1.2 2001/06/27 20:18:35 nagler Exp $

=cut

1;
