# Copyright (c) 2001 bivio Inc.  All rights reserved.
#
# This program is free software and is provided "as is" without express
# or implied warranty.  It may be used, redistributed, and/or modified
# under the terms of the Perl Artistic License:
# http://www.opensource.org/licenses/artistic-license.html
# 
# $Id: ViewShortcuts.pm,v 1.1 2001/06/27 05:50:51 nagler Exp $
package BivioNet::UI::ViewShortcuts;
use strict;
$BivioNet::UI::ViewShortcuts::VERSION = sprintf('%d.%02d', q$Revision: 1.1 $ =~ /\d+/g);
$_ = $BivioNet::UI::ViewShortcuts::VERSION;

=head1 NAME

BivioNet::UI::ViewShortcuts - view convenience methods

=head1 RELEASE SCOPE

bOP

=head1 SYNOPSIS

    use BivioNet::UI::ViewShortcuts;

=cut

=head1 EXTENDS

L<Bivio::UI::ViewShortcuts>

=cut

use Bivio::UI::ViewShortcuts;
@BivioNet::UI::ViewShortcuts::ISA = ('Bivio::UI::ViewShortcuts');

=head1 DESCRIPTION

C<BivioNet::UI::ViewShortcuts>

=cut

#=IMPORTS

#=VARIABLES

=head1 METHODS

=cut

=for html <a name="vs_bullets"></a>

=head2 static vs_bullets(array_ref bullets) : Bivio::UI::Widget

Returns a widget which contains the bulletted points.  Uses
a Join widget.  May be nested.

=cut

sub vs_bullets {
    my($proto, $bullets) = @_;
    return $proto->vs_call('Join', _bullet_map($bullets))
}

=for html <a name="vs_petstore"></a>

=head2 static vs_petstore(string label, string href) : Bivio::UI::Widget

Creates a link to the petstore.  Hack to jump right now.

=cut

sub vs_petstore {
    my($proto, $label, $href) = @_;
    return $proto->vs_call('Link',
	$proto->vs_call('String', $label),
	'http://www.jump.bivio.com:8088'.$href);
}

=for html <a name="vs_space"></a>

=head2 static vs_space() : Bivio::UI::Widget

Returns a widget which renders a single &nbsp; value.

=head2 static vs_space(int count) : Bivio::UI::Widget

Returns a widget which renders a series of &nbsp; values.

=cut

sub vs_space {
    my($proto, $count) = @_;
    $count ||= 1;
    return $proto->vs_call('Join', ['&nbsp;' x $count]);
}

=for html <a name="vs_view_as_plain_text"></a>

=head2 static vs_view_as_plain_text() : Bivio::UI::Widget

Returns a widget which generates a link to this view's source.

=cut

sub vs_view_as_plain_text {
    my($proto) = @_;
    return $proto->vs_call('Prose',
	    "Link(Image('attachment_w_on'),
                [['->get_request'], '->format_uri',
		Bivio::Agent::TaskId->VIEW_AS_PLAIN_TEXT,
		undef, undef,
		view_widget_value('view_name')]);");
}

#=PRIVATE METHODS

# _bullet_map(array_ref bullets) : array_ref
#
# Returns a join of its arguments as a bulleted list.
#
sub _bullet_map {
    my($bullets) = @_;
    return [
	"<ul>\n",
	(
	    map {
		((ref($_) eq 'ARRAY' ? @{_bullet_map($_)}
			: ('<li> ', $_)),
		 "<p>\n",
		);
	    } @$bullets,
	),
	"</ul>\n",
    ];
}

=head1 COPYRIGHT

Copyright (c) 2001 bivio Inc.  All rights reserved.

This program is free software and is provided "as is" without express
or implied warranty.  It may be used, redistributed, and/or modified
under the terms of the Perl Artistic License:
http://www.opensource.org/licenses/artistic-license.html

=head1 VERSION

$Id: ViewShortcuts.pm,v 1.1 2001/06/27 05:50:51 nagler Exp $

=cut

1;
